@@ -1,7 +1,8 @@
 # import submodules you want to install
-
-from .logging import *
+from .decorators import *
 from .tools import *
+from .log import *
+from .alerts import *
 
 
 __docformat__ = "restructuredtext"
